@@ -38,6 +38,7 @@ logger = logging.getLogger(__name__)
 
 
 @click.group()
+@click.version_option(version=__version__)
 @click.option('--name', '-n', default='reV', type=STR,
               help='Job name. Default is "reV".')
 @click.option('--config_file', '-c',
@@ -54,14 +55,6 @@ def main(ctx, name, config_file, verbose):
     ctx.obj['VERBOSE'] = verbose
 
 
-@main.command()
-def version():
-    """
-    print version
-    """
-    click.echo(__version__)
-
-
 @main.group(invoke_without_command=True)
 @click.option('-v', '--verbose', is_flag=True,
               help='Flag to turn on debug logging.')
@@ -111,7 +104,7 @@ def valid_econ_keys(ctx):
               help='Flag to turn on debug logging.')
 @click.pass_context
 def offshore(ctx, verbose):
-    """Offshore gen/econ aggregation with ORCA."""
+    """Offshore gen/econ aggregation with NRWAL."""
     if ctx.invoked_subcommand is None:
         config_file = ctx.obj['CONFIG_FILE']
         verbose = any([verbose, ctx.obj['VERBOSE']])
