@@ -187,6 +187,7 @@ def submit_from_config(ctx, name, cf_file, year, config, verbose):
                    module=config.execution_control.module,
                    conda_env=config.execution_control.conda_env,
                    stdout_path=os.path.join(config.logdir, 'stdout'),
+                   sh_script=config.execution_control.sh_script,
                    verbose=verbose)
 
 
@@ -482,11 +483,14 @@ def get_node_cmd(name, sam_files, cf_file, out_fpath, year=None,
 @click.option('--stdout_path', '-sout', default='./out/stdout', type=STR,
               show_default=True,
               help='Subprocess standard output path. Default is ./out/stdout')
+@click.option('--sh_script', '-sh', default=None, type=STR,
+              show_default=True,
+              help='Extra shell script commands to run before the reV call.')
 @click.option('-v', '--verbose', is_flag=True,
               help='Flag to turn on debug logging. Default is not verbose.')
 @click.pass_context
 def slurm(ctx, alloc, nodes, memory, walltime, feature, module, conda_env,
-          stdout_path, verbose):
+          stdout_path, sh_script, verbose):
     """Run econ on HPC via SLURM job submission."""
 
     name = ctx.obj['NAME']
@@ -528,6 +532,9 @@ def slurm(ctx, alloc, nodes, memory, walltime, feature, module, conda_env,
                            logdir=logdir, output_request=output_request,
                            append=append, verbose=verbose)
 
+        if sh_script:
+            cmd = sh_script + '\n' + cmd
+
         status = Status.retrieve_job_status(dirout, 'econ', node_name,
                                             hardware='eagle',
                                             subprocess_manager=slurm_manager)
